@@ -199,6 +199,8 @@ class PreferencesTestdrivegtkDialog(gtk.Dialog):
         self.chk_flavor_lubuntu.connect("clicked", self.on_select_flavors)
         self.chk_flavor_ubuntukylin = self.builder.get_object("chk_flavor_ubuntukylin")
         self.chk_flavor_ubuntukylin.connect("clicked", self.on_select_flavors)
+        self.chk_flavor_ubuntugnome = self.builder.get_object("chk_flavor_ubuntugnome")
+        self.chk_flavor_ubuntugnome.connect("clicked", self.on_select_flavors)
         self.chk_flavor_other = self.builder.get_object("chk_flavor_other")
         self.chk_flavor_other.connect("clicked", self.on_select_flavors)
 
@@ -302,6 +304,8 @@ class PreferencesTestdrivegtkDialog(gtk.Dialog):
                     self.chk_flavor_lubuntu.set_active(True)
                 elif flavor == 'ubuntukylin':
                     self.chk_flavor_ubuntukylin.set_active(True)
+                elif flavor == 'ubuntugnome':
+                    self.chk_flavor_ubuntugnome.set_active(True)
                 elif flavor == 'other':
                     self.chk_flavor_other.set_active(True)
                 else:
@@ -447,6 +451,8 @@ class PreferencesTestdrivegtkDialog(gtk.Dialog):
             self.flavors = self.flavors + "lubuntu, "
         if self.chk_flavor_ubuntukylin.get_active():
             self.flavors = self.flavors + "ubuntukylin, "
+        if self.chk_flavor_ubuntugnome.get_active():
+            self.flavors = self.flavors + "ubuntugnome, "
         if self.chk_flavor_other.get_active():
             self.flavors = self.flavors + "other, "
 
